==> OrnamentBook-0.1.0.tar.gz: OrnamentBook-0.1.0/ornamentbook/main.py <==
#!/usr/bin/env python
# -*- mode: python; coding: koi8-r; -*-
# (c) Con Radchenko mailto:bofh@pochta.ru

import sys, os
from glob import glob
import shelve

import gtk
from gtk import TRUE, FALSE
from gtk import glade
from gtk import gdk
import pango

import ornamentbook
from detectcharset import detectcharset

gf = 'ornamentbook.glade'
config_dir = os.path.expanduser('~/.pybr')
rc_file = os.path.expanduser('~/.pybr/ornamentbook.rc')
user_skin_dir = os.path.expanduser('~/.pybr/skins')


class NewPyBR:

    def __init__(self):

        self.recent_files = []
        # recent_files: list:
        # [
        #   [filename, line_index, char_index, encoding],
        #   ...
        # ]
        self.num_recent_files = 40
        self.filename = None
        self.encoding = 'utf-8'

        self.create_widgets()


    def create_widgets(self):

        glade_file = None

        for d in sys.path:
            f = os.path.join(d, 'ornamentbook', gf)
            if os.path.exists(f):
                glade_file = f
                break

        if not glade_file:
            sys.exit('ERROR: can\'t find glade file')

        wTree = glade.XML(glade_file, 'main_window')
        self.glade_file = glade_file

        wTree.signal_autoconnect(self)

        self.window = wTree.get_widget('main_window')
        top_vbox = wTree.get_widget('top_vbox')
        text_widget = ornamentbook.OrnamentBook(self.window)
        top_vbox.pack_start(text_widget)

        text_widget.realize()
        text_widget.connect('position-changed', self.position_changed_cb)
        self.text_widget = text_widget

        self.open_recent_file_menu = wTree.get_widget('open_recent_file_menu')
        self.skin_menu = wTree.get_widget('skin_menu')
        self.percent_label = wTree.get_widget('percent_label')

        self.read_properties()

        self.update_skin_menu()

        self.window.show_all()
        #text_widget.grab_focus()

    def position_changed_cb(self, w, pos):
        self.percent_label.set_text('%d %%' % int(pos*100))


    def open_file(self, filename):
        #print 'open_file', filename

        try:
            fd = open(filename)
        except IOError, err:
            sys.stderr.write('ERROR: can\'t open file: %s: %s\n'
                             % (filename, err[1]))
            return

        if self.filename: # save previous file
            self.add_file_to_recent(self.filename,
                                    self.text_widget.current_page_line_index,
                                    self.text_widget.current_page_char_index,
                                    self.encoding)

        text = fd.read()
        rf = self.get_recent_file(filename)
        if rf:
            self.encoding = rf[3]
        else:
            fd.seek(0)
            enc = detectcharset(fd)
            if enc:
                self.encoding = enc
            else:
                self.encoding = 'iso8859-1'
        text = unicode(text, self.encoding)
        if rf:
            self.text_widget.set_text(text, rf[1], rf[2])
        else:
            self.text_widget.set_text(text)
        self.text_widget.draw_text()
        self.filename = filename

        self.add_file_to_recent(self.filename,
                                self.text_widget.current_page_line_index,
                                self.text_widget.current_page_char_index,
                                self.encoding)

        self.update_recent_files_menu()


    def read_properties(self):
        try:
            sh = shelve.open(rc_file)
        except IOError, err:
            sys.stderr.write('ERROR: can\'t open rc file: %s: %s\n'
                             % (rc_file, err[1]))
            return

        if sh.has_key('width'):
            width = sh['width']
            height = sh['height']
            self.window.resize(width, height)
            self.recent_files = sh['recent_files']
            self.text_widget.left_page_right_margin = sh['left_page_right_margin']
            self.text_widget.right_page_left_margin = sh['right_page_left_margin']
            self.text_widget.left_page_left_margin = sh['left_page_left_margin']
            self.text_widget.right_page_right_margin = sh['right_page_right_margin']
            self.text_widget.top_margin = sh['top_margin']
            self.text_widget.bottom_margin = sh['bottom_margin']
            self.text_widget.set_tab_width(sh['tabs_width'])
            self.text_widget.set_font(sh['font'])
            self.text_widget.color = gdk.color_parse(sh['foreground_color'])
            self.text_widget.set_skin(sh['skin'])

        sh.close()

        if self.recent_files:
            gtk.idle_add(self.open_file, self.recent_files[-1][0])


    def save_properties(self):
        try:
            sh = shelve.open(rc_file)
        except IOError, err:
            sys.stderr.write('ERROR: can\'t open rc file: %s: %s'
                             % (rc_file, err[1]))
            return

        width, height = self.window.get_size()
        sh['width'] = width
        sh['height'] = height
        if self.filename:
            self.add_file_to_recent(self.filename,
                                    self.text_widget.current_page_line_index,
                                    self.text_widget.current_page_char_index,
                                    self.encoding)
        sh['recent_files'] = self.recent_files

        sh['left_page_left_margin'] = self.text_widget.left_page_left_margin
        sh['left_page_right_margin'] = self.text_widget.left_page_right_margin
        sh['right_page_left_margin'] = self.text_widget.right_page_left_margin
        sh['right_page_right_margin'] = self.text_widget.right_page_right_margin
        sh['top_margin'] = self.text_widget.top_margin
        sh['bottom_margin'] = self.text_widget.bottom_margin
        sh['tabs_width'] = self.text_widget.tabs_width

        color = '#%02x%02x%02x' % (self.text_widget.color.red>>8,
                                   self.text_widget.color.green>>8,
                                   self.text_widget.color.blue>>8)
        sh['foreground_color'] = color

        font = self.text_widget.font.to_string()
        sh['font'] = font
        sh['skin'] = self.text_widget.skin_file

        sh.close()


    def update_recent_files_menu(self):
        menu = gtk.Menu()
        menu.show()
        for f in self.recent_files:
            menuitem = gtk.MenuItem(fix_filename(f[0]))
            menuitem.get_child().set_use_underline(FALSE)
            menuitem.connect('activate', self.recent_files_activate_cb, f[0])
            menu.add(menuitem)
            menuitem.show()
        self.open_recent_file_menu.set_submenu(menu)


    def update_skin_menu(self):

        skins = []
        if os.path.exists(user_skin_dir) and os.path.isdir(user_skin_dir):
            skins_dirs = [user_skin_dir]
        else:
            skins_dirs = []

        for d in sys.path:
            f = os.path.join(d, 'ornamentbook', ornamentbook.skins_dir)
            if os.path.exists(f) and os.path.isdir(f):
                skins_dirs.append(f)
                break

        for d in skins_dirs:
            f = os.path.join(d, '*.jpg')
            skins.extend(glob(f))

        menu = gtk.Menu()
        menu.show()
        for f in skins:
            fn = os.path.abspath(f)
            menuitem = gtk.MenuItem(fn)
            menuitem.get_child().set_use_underline(FALSE)
            menuitem.connect('activate', self.skin_menu_activate_cb, fn)
            menu.add(menuitem)
            menuitem.show()
        self.skin_menu.set_submenu(menu)


    def skin_menu_activate_cb(self, w, filename):
        #print 'skin_menu_activate_cb', filename
        self.text_widget.set_skin(filename)
        self.text_widget.draw_text()


    def recent_files_activate_cb(self, w, filename):
        #print 'recent_files_activate_cb', filename
        self.open_file(filename)


    def get_recent_file(self, filename):
        #print 'get_recent_file', filename
        for f in self.recent_files:
            if f[0] == filename:
                return f
        return None


    def add_file_to_recent(self, filename, line, index, encoding):
        #print 'add_file_to_recent', filename
        i = 0
        for f in self.recent_files:
            if f[0] == filename:
                del self.recent_files[i]
                break
            i+=1
        if len(self.recent_files) > self.num_recent_files:
            del self.recent_files[0]
        self.recent_files.append((filename, line, index, encoding))

        #self.update_recent_files_menu()


    def on_open_activate(self, *args):
        dialog = gtk.FileSelection()
        dialog.set_transient_for(self.window)
        dialog.show()

        response = dialog.run()

        if response == gtk.RESPONSE_OK:
            filename = dialog.get_filename()
            self.open_file(filename)

        dialog.destroy()


    def on_go_to_position_activate(self, *args):
        s = entry_dialog(self.window, 'Go to position', 'Go to position: (%) ')
        try:
            pos = float(s)
        except:
            return
        if 100 < pos < 0:
            return
        self.text_widget.set_position(pos/100)


    def on_quit_activate(self, *args):
        self.window.destroy()


    def on_main_window_unrealize(self, *args):
        #print 'on_main_window_unrealize'
        self.save_properties()

    def on_properties_activate(self, *args):
        #print 'on_properties_activate'
        wTree = glade.XML(self.glade_file, 'properties_dialog')
        # move dialog to centre of parrent window
        dialog = wTree.get_widget('properties_dialog')
        dialog.set_transient_for(self.window)
        x, y = self.window.get_position()
        w, h = self.window.get_size()
        dw, dh = dialog.get_size()
        dx = x + (w-dw)/2
        dy = y + (h-dh)/2
        dialog.move(dx, dy)
        dialog.show()
        dic = {
            'on_close_properties_clicked' :
            (lambda w: dialog.destroy()),
            'on_font_select_clicked' :
            (lambda w: self.on_font_select_clicked(dialog, 'font')),
            'on_foreground_color_clicked' :
            (lambda w: self.on_color_select_clicked(dialog, 'foreground_color')),
            'on_apply_properties_clicked' :
            self.apply_properties_cb,
            }
        wTree.signal_autoconnect(dic)

        self.left_page_left_margin_spinbutton \
             = wTree.get_widget('left_page_left_margin_spinbutton')
        self.left_page_right_margin_spinbutton \
             = wTree.get_widget('left_page_right_margin_spinbutton')
        self.right_page_left_margin_spinbutton \
             = wTree.get_widget('right_page_left_margin_spinbutton')
        self.right_page_right_margin_spinbutton \
             = wTree.get_widget('right_page_right_margin_spinbutton')

        self.top_margin_spinbutton \
             = wTree.get_widget('top_margin_spinbutton')
        self.bottom_margin_spinbutton \
             = wTree.get_widget('bottom_margin_spinbutton')

        self.tabs_width_spinbutton = wTree.get_widget('tabs_width_spinbutton')

        self.left_page_left_margin_spinbutton.set_value(self.text_widget.left_page_left_margin)
        self.left_page_right_margin_spinbutton.set_value(self.text_widget.left_page_right_margin)
        self.right_page_left_margin_spinbutton.set_value(self.text_widget.right_page_left_margin)
        self.right_page_right_margin_spinbutton.set_value(self.text_widget.right_page_right_margin)

        self.top_margin_spinbutton.set_value(self.text_widget.top_margin)
        self.bottom_margin_spinbutton.set_value(self.text_widget.bottom_margin)

        self.tabs_width_spinbutton.set_value(self.text_widget.tabs_width)



    def apply_properties_cb(self, *args):
        #print 'apply_properties_cb'

        self.text_widget.left_page_left_margin = self.left_page_left_margin_spinbutton.get_value()
        self.text_widget.left_page_right_margin = self.left_page_right_margin_spinbutton.get_value()
        self.text_widget.right_page_left_margin = self.right_page_left_margin_spinbutton.get_value()
        self.text_widget.right_page_right_margin = self.right_page_right_margin_spinbutton.get_value()
        self.text_widget.top_margin = self.top_margin_spinbutton.get_value()
        self.text_widget.bottom_margin = self.bottom_margin_spinbutton.get_value()
        self.text_widget.set_tab_width(int(self.tabs_width_spinbutton.get_value()))
        self.text_widget.draw_text()

## inside_margin_spinbutton
## outside_margin_spinbutton
## top_margin_spinbutton
## bottom_margin_spinbutton


    def on_font_select_clicked(self, parent, prop):
        #print 'on_font_select_clicked'
        dialog = gtk.FontSelectionDialog('Select font')
        dialog.set_transient_for(parent)
        dialog.show()

        response = dialog.run()
        if response  == gtk.RESPONSE_OK:
            font = dialog.get_font_name()
            self.text_widget.set_font(font)
            self.text_widget.draw_text()
            #props = {prop: font}
            #self.apply_properties(props)

        dialog.destroy()


    def on_color_select_clicked(self, parent, prop):
        #print 'on_color_clicked'
        dialog = gtk.ColorSelectionDialog('Select color')

        dialog.colorsel.set_has_palette(TRUE)
        dialog.set_transient_for(parent)
        dialog.show()

        response = dialog.run()

        if response == gtk.RESPONSE_OK:

            color = dialog.colorsel.get_current_color()
            self.text_widget.color = color
            self.text_widget.draw_text()
            #color_val = '#%02x%02x%02x' \
            #            % (color.red>>8, color.green>>8, color.blue>>8)
            #props = {prop: color_val}
            #self.apply_properties(props)

        dialog.destroy()

##----------------------------------------------------------------------

import locale

default_encoding = locale.getlocale()[1]
if not default_encoding:
    default_encoding='iso8859-1'

def entry_dialog(parent, title, label_text, text=''):

    dialog = gtk.Dialog(title, parent,
                        gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                        (gtk.STOCK_OK, gtk.RESPONSE_OK,
                         gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT))
    hbox = gtk.HBox()
    dialog.vbox.pack_start(hbox, TRUE, TRUE, 0)
    label = gtk.Label(label_text)
    hbox.pack_start(label, expand=FALSE)
    entry = gtk.Entry()
    entry.set_text(text)
    entry.connect('activate', lambda w:
                  dialog.emit ('response', gtk.RESPONSE_OK))
    hbox.pack_start(entry)
    dialog.show_all()
    response = dialog.run()
    str = None
    if response == gtk.RESPONSE_OK:
        str = entry.get_text()
    dialog.destroy()
    return str

def fix_filename(filename):
    # from locale encoding to utf-8
    # TODO: G_BROKEN_FILENAMES
    enc = default_encoding
    fn = filename.decode(enc).encode('utf-8')
    return fn

##----------------------------------------------------------------------

if __name__ == '__main__':
    try:
        os.mkdir(config_dir)
    except:
        pass


    npbr = NewPyBR()
    npbr.window.connect('destroy', lambda w: gtk.main_quit())
    gtk.main()

==> OrnamentBook-0.1.1.tar.gz: OrnamentBook-0.1.1/ornamentbook/main.py <==
#!/usr/bin/env python
# -*- mode: python; coding: koi8-r; -*-
# (c) Con Radchenko mailto:bofh@pochta.ru

import sys, os
from glob import glob
import shelve

import gtk
from gtk import TRUE, FALSE
from gtk import glade
from gtk import gdk
import pango

import ornamentbook
#from detectcharset import detectcharset

gf = 'ornamentbook.glade'
config_dir = os.path.expanduser('~/.pybr')
rc_file = os.path.expanduser('~/.pybr/ornamentbook.rc')
user_skin_dir = os.path.expanduser('~/.pybr/skins')


class NewPyBR:

    def __init__(self):

        self.recent_files = []
        # recent_files: list:
        # [
        #   [filename, line_index, char_index, encoding],
        #   ...
        # ]
        self.num_recent_files = 40
        self.filename = None
        self.encoding = 'utf-8'

        self.create_widgets()


    def create_widgets(self):

        glade_file = None

        for d in sys.path:
            f = os.path.join(d, 'ornamentbook', gf)
            if os.path.exists(f):
                glade_file = f
                break

        if not glade_file:
            sys.exit('ERROR: can\'t find glade file')

        wTree = glade.XML(glade_file, 'main_window')
        self.glade_file = glade_file

        wTree.signal_autoconnect(self)

        self.window = wTree.get_widget('main_window')
        top_vbox = wTree.get_widget('top_vbox')
        text_widget = ornamentbook.OrnamentBook(self.window)
        top_vbox.pack_start(text_widget)

        text_widget.realize()
        text_widget.connect('position-changed', self.position_changed_cb)
        self.text_widget = text_widget

        self.open_recent_file_menu = wTree.get_widget('open_recent_file_menu')
        self.skin_menu = wTree.get_widget('skin_menu')
        self.percent_label = wTree.get_widget('percent_label')

        self.read_properties()

        self.update_skin_menu()

        self.window.show_all()
        #text_widget.grab_focus()

    def position_changed_cb(self, w, pos):
        self.percent_label.set_text('%d %%' % int(pos*100))


    def open_file(self, filename):
        #print 'open_file', filename

        try:
            open(filename)
        except IOError, err:
            sys.stderr.write('ERROR: can\'t open file: %s: %s\n'
                             % (filename, err[1]))
            return

        if self.filename: # save previous file
            #print 'save previous file', self.text_widget.current_page_line_index
            self.add_file_to_recent(self.filename,
                                    self.text_widget.current_page_line_index,
                                    self.text_widget.current_page_char_index,
                                    self.encoding)



        rf = self.get_recent_file(filename)

        if rf:
            self.text_widget.open_file(filename, rf[3], rf[1], rf[2])
        else:
            self.text_widget.open_file(filename)


        self.filename = filename

        self.add_file_to_recent(self.filename,
                                self.text_widget.current_page_line_index,
                                self.text_widget.current_page_char_index,
                                self.encoding)

        self.update_recent_files_menu()



    def read_properties(self):
        try:
            sh = shelve.open(rc_file)
        except IOError, err:
            sys.stderr.write('ERROR: can\'t open rc file: %s: %s\n'
                             % (rc_file, err[1]))
            return

        if sh.has_key('width'):
            width = sh['width']
            height = sh['height']
            self.window.resize(width, height)
            self.recent_files = sh['recent_files']
            self.text_widget.left_page_right_margin = sh['left_page_right_margin']
            self.text_widget.right_page_left_margin = sh['right_page_left_margin']
            self.text_widget.left_page_left_margin = sh['left_page_left_margin']
            self.text_widget.right_page_right_margin = sh['right_page_right_margin']
            self.text_widget.top_margin = sh['top_margin']
            self.text_widget.bottom_margin = sh['bottom_margin']
            self.text_widget.set_tab_width(sh['tabs_width'])
            self.text_widget.set_font(sh['font'])
            self.text_widget.color = gdk.color_parse(sh['foreground_color'])
            self.text_widget.set_skin(sh['skin'])

        sh.close()

        if self.recent_files:
            gtk.idle_add(self.open_file, self.recent_files[-1][0])


    def save_properties(self):
        try:
            sh = shelve.open(rc_file)
        except IOError, err:
            sys.stderr.write('ERROR: can\'t open rc file: %s: %s'
                             % (rc_file, err[1]))
            return

        width, height = self.window.get_size()
        sh['width'] = width
        sh['height'] = height
        if self.filename:
            self.add_file_to_recent(self.filename,
                                    self.text_widget.current_page_line_index,
                                    self.text_widget.current_page_char_index,
                                    self.encoding)
        sh['recent_files'] = self.recent_files

        sh['left_page_left_margin'] = self.text_widget.left_page_left_margin
        sh['left_page_right_margin'] = self.text_widget.left_page_right_margin
        sh['right_page_left_margin'] = self.text_widget.right_page_left_margin
        sh['right_page_right_margin'] = self.text_widget.right_page_right_margin
        sh['top_margin'] = self.text_widget.top_margin
        sh['bottom_margin'] = self.text_widget.bottom_margin
        sh['tabs_width'] = self.text_widget.tabs_width

        color = '#%02x%02x%02x' % (self.text_widget.color.red>>8,
                                   self.text_widget.color.green>>8,
                                   self.text_widget.color.blue>>8)
        sh['foreground_color'] = color

        font = self.text_widget.font.to_string()
        sh['font'] = font
        sh['skin'] = self.text_widget.skin_file

        sh.close()


    def update_recent_files_menu(self):
        menu = gtk.Menu()
        menu.show()
        for f in self.recent_files:
            menuitem = gtk.MenuItem(fix_filename(f[0]))
            menuitem.get_child().set_use_underline(FALSE)
            menuitem.connect('activate', self.recent_files_activate_cb, f[0])
            menu.add(menuitem)
            menuitem.show()
        self.open_recent_file_menu.set_submenu(menu)


    def update_skin_menu(self):

        skins = []
        if os.path.exists(user_skin_dir) and os.path.isdir(user_skin_dir):
            skins_dirs = [user_skin_dir]
        else:
            skins_dirs = []

        for d in sys.path:
            f = os.path.join(d, 'ornamentbook', ornamentbook.skins_dir)
            if os.path.exists(f) and os.path.isdir(f):
                skins_dirs.append(f)
                break

        for d in skins_dirs:
            f = os.path.join(d, '*.jpg')
            skins.extend(glob(f))

        menu = gtk.Menu()
        menu.show()
        for f in skins:
            fn = os.path.abspath(f)
            menuitem = gtk.MenuItem(fn)
            menuitem.get_child().set_use_underline(FALSE)
            menuitem.connect('activate', self.skin_menu_activate_cb, fn)
            menu.add(menuitem)
            menuitem.show()
        self.skin_menu.set_submenu(menu)


    def skin_menu_activate_cb(self, w, filename):
        #print 'skin_menu_activate_cb', filename
        self.text_widget.set_skin(filename)
        self.text_widget.draw_text()


    def recent_files_activate_cb(self, w, filename):
        #print 'recent_files_activate_cb', filename
        self.open_file(filename)


    def get_recent_file(self, filename):
        #print 'get_recent_file', filename
        for f in self.recent_files:
            if f[0] == filename:
                return f
        return None


    def add_file_to_recent(self, filename, line, index, encoding):
        #print 'add_file_to_recent', filename, line, index, encoding
        i = 0
        for f in self.recent_files:
            if f[0] == filename:
                del self.recent_files[i]
                break
            i+=1
        if len(self.recent_files) > self.num_recent_files:
            del self.recent_files[0]
        self.recent_files.append((filename, line, index, encoding))

        #self.update_recent_files_menu()


    def on_open_activate(self, *args):
        dialog = gtk.FileSelection()
        dialog.set_transient_for(self.window)
        dialog.show()

        response = dialog.run()

        if response == gtk.RESPONSE_OK:
            filename = dialog.get_filename()
            self.open_file(filename)

        dialog.destroy()


    def on_go_to_position_activate(self, *args):
        s = entry_dialog(self.window, 'Go to position', 'Go to position: (%) ')
        try:
            pos = float(s)
        except:
            return
        if 100 < pos < 0:
            return
        self.text_widget.set_position(pos/100)


    def on_quit_activate(self, *args):
        self.window.destroy()


    def on_main_window_unrealize(self, *args):
        #print 'on_main_window_unrealize'
        self.save_properties()

    def on_properties_activate(self, *args):
        #print 'on_properties_activate'
        wTree = glade.XML(self.glade_file, 'properties_dialog')
        # move dialog to centre of parrent window
        dialog = wTree.get_widget('properties_dialog')
        dialog.set_transient_for(self.window)
        x, y = self.window.get_position()
        w, h = self.window.get_size()
        dw, dh = dialog.get_size()
        dx = x + (w-dw)/2
        dy = y + (h-dh)/2
        dialog.move(dx, dy)
        dialog.show()
        dic = {
            'on_close_properties_clicked' :
            (lambda w: dialog.destroy()),
            'on_font_select_clicked' :
            (lambda w: self.on_font_select_clicked(dialog, 'font')),
            'on_foreground_color_clicked' :
            (lambda w: self.on_color_select_clicked(dialog, 'foreground_color')),
            'on_apply_properties_clicked' :
            self.apply_properties_cb,
            }
        wTree.signal_autoconnect(dic)

        self.left_page_left_margin_spinbutton \
             = wTree.get_widget('left_page_left_margin_spinbutton')
        self.left_page_right_margin_spinbutton \
             = wTree.get_widget('left_page_right_margin_spinbutton')
        self.right_page_left_margin_spinbutton \
             = wTree.get_widget('right_page_left_margin_spinbutton')
        self.right_page_right_margin_spinbutton \
             = wTree.get_widget('right_page_right_margin_spinbutton')

        self.top_margin_spinbutton \
             = wTree.get_widget('top_margin_spinbutton')
        self.bottom_margin_spinbutton \
             = wTree.get_widget('bottom_margin_spinbutton')

        self.tabs_width_spinbutton = wTree.get_widget('tabs_width_spinbutton')

        self.left_page_left_margin_spinbutton.set_value(self.text_widget.left_page_left_margin)
        self.left_page_right_margin_spinbutton.set_value(self.text_widget.left_page_right_margin)
        self.right_page_left_margin_spinbutton.set_value(self.text_widget.right_page_left_margin)
        self.right_page_right_margin_spinbutton.set_value(self.text_widget.right_page_right_margin)

        self.top_margin_spinbutton.set_value(self.text_widget.top_margin)
        self.bottom_margin_spinbutton.set_value(self.text_widget.bottom_margin)

        self.tabs_width_spinbutton.set_value(self.text_widget.tabs_width)



    def apply_properties_cb(self, *args):
        #print 'apply_properties_cb'

        self.text_widget.left_page_left_margin = self.left_page_left_margin_spinbutton.get_value()
        self.text_widget.left_page_right_margin = self.left_page_right_margin_spinbutton.get_value()
        self.text_widget.right_page_left_margin = self.right_page_left_margin_spinbutton.get_value()
        self.text_widget.right_page_right_margin = self.right_page_right_margin_spinbutton.get_value()
        self.text_widget.top_margin = self.top_margin_spinbutton.get_value()
        self.text_widget.bottom_margin = self.bottom_margin_spinbutton.get_value()
        self.text_widget.set_tab_width(int(self.tabs_width_spinbutton.get_value()))
        self.text_widget.draw_text()

## inside_margin_spinbutton
## outside_margin_spinbutton
## top_margin_spinbutton
## bottom_margin_spinbutton


    def on_font_select_clicked(self, parent, prop):
        #print 'on_font_select_clicked'
        dialog = gtk.FontSelectionDialog('Select font')
        dialog.set_transient_for(parent)
        dialog.show()

        response = dialog.run()
        if response  == gtk.RESPONSE_OK:
            font = dialog.get_font_name()
            self.text_widget.set_font(font)
            self.text_widget.set_tab_width()
            self.text_widget.draw_text()
            #props = {prop: font}
            #self.apply_properties(props)

        dialog.destroy()


    def on_color_select_clicked(self, parent, prop):
        #print 'on_color_clicked'
        dialog = gtk.ColorSelectionDialog('Select color')

        dialog.colorsel.set_has_palette(TRUE)
        dialog.set_transient_for(parent)
        dialog.show()

        response = dialog.run()

        if response == gtk.RESPONSE_OK:

            color = dialog.colorsel.get_current_color()
            self.text_widget.color = color
            self.text_widget.draw_text()
            #color_val = '#%02x%02x%02x' \
            #            % (color.red>>8, color.green>>8, color.blue>>8)
            #props = {prop: color_val}
            #self.apply_properties(props)

        dialog.destroy()

##----------------------------------------------------------------------

import locale

default_encoding = locale.getlocale()[1]
if not default_encoding:
    default_encoding='iso8859-1'

def entry_dialog(parent, title, label_text, text=''):

    dialog = gtk.Dialog(title, parent,
                        gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                        (gtk.STOCK_OK, gtk.RESPONSE_OK,
                         gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT))
    hbox = gtk.HBox()
    dialog.vbox.pack_start(hbox, TRUE, TRUE, 0)
    label = gtk.Label(label_text)
    hbox.pack_start(label, expand=FALSE)
    entry = gtk.Entry()
    entry.set_text(text)
    entry.connect('activate', lambda w:
                  dialog.emit ('response', gtk.RESPONSE_OK))
    hbox.pack_start(entry)
    dialog.show_all()
    response = dialog.run()
    str = None
    if response == gtk.RESPONSE_OK:
        str = entry.get_text()
    dialog.destroy()
    return str

def fix_filename(filename):
    # from locale encoding to utf-8
    # TODO: G_BROKEN_FILENAMES
    enc = default_encoding
    fn = filename.decode(enc).encode('utf-8')
    return fn

##----------------------------------------------------------------------

if __name__ == '__main__':
    try:
        os.mkdir(config_dir)
    except:
        pass


    npbr = NewPyBR()
    npbr.window.connect('destroy', lambda w: gtk.main_quit())
    gtk.main()
